@@ -1,3 +1,5 @@
+from abc import ABC
+
 from .util.logging import get_logger
 from .util.dict import recdefaultdict, merge_dicts
 from .persistload import PersistLoadBasic, PersistLoadWithParameters
@@ -6,7 +8,7 @@ from copy import deepcopy
 
 
 # Base classes
-class Persistable:
+class Persistable(ABC):
     """
     A persistable logged object useful for ML use-cases.
     
@@ -38,7 +40,7 @@ class Persistable:
             Params describing the payload (these should uniquely define the payload of a given name)
         required_params         : list or tuple
             List of required parameters
-        working_subdir          : str or pathlib.Path
+        workingdatapath         : str or pathlib.Path
             The working directory, which is by default under the local-data directory, but can by overridden by
             passing a full pathlib.Path argument
         persistloadtype         : str
@@ -68,7 +70,7 @@ class Persistable:
             # ToDo: make this nicer
             workingdatapath = from_persistable_object[0].persistload.workingdatapath
             persistloadtype = from_persistable_object[0].persistload.get_type()
-            params          = merge_dicts(
+            params = merge_dicts(
                 params,
                 {
                     persistable_object.payload_name: persistable_object.fn_params
@@ -78,6 +80,9 @@ class Persistable:
         elif workingdatapath is None:
             raise ValueError("'workingdatapath' must be specified if not provided by another Persistable object")
 
+        # Check params:
+        self._validate_params(params=params)
+
         # Initialize payload:
         self.payload = recdefaultdict()
 
@@ -109,9 +114,9 @@ class Persistable:
         # ToDo Improve logging control and output:
         class_name = self.__class__.__name__
         if verbose:
-            console_level=INFO
+            console_level = INFO
         else:
-            console_level=WARNING
+            console_level = WARNING
         self.logger = get_logger(
             class_name,
             file_loc=(self.persistload.workingdatapath / f"{class_name}.log"),
@@ -174,6 +179,62 @@ class Persistable:
         del self.payload
         self.payload = recdefaultdict()
 
+    def update_fn_params(self, new_fn_params: dict, delete_old: bool=True):
+        """
+        Updates fn_params (that uniquely define the payload along with the payload_name) and renames the persisted
+        payload file accordingly.
+
+        Convenience method when, during development, parameter names or values are refactored but the developer
+        does not wishs to regenerate all her persistable payloads.
+
+        Parameters
+        ----------
+        new_fn_params   : dict
+            New fn_params to pin to the Persistable object.
+        delete_old      : bool
+            Use False to keep old parameterized payload file (sometimes useful for backwards compatibility).
+            Use True to remove the old parameterized payload file (garbage collecting and storage friendly default).
+
+        Returns
+        -------
+
+        """
+        # Rename payload file:
+        self.persistload.rename(
+            self.payload_name, self.payload_name, self.fn_params, new_fn_params, delete_old=delete_old
+        )
+
+        # Update params:
+        self.fn_params = new_fn_params
+
+    def update_payload_name(self, new_payload_name: str, delete_old: bool=True):
+        """
+        Updates payload_name (that uniquely define the payload along with the fn_params) and renames the persisted
+        payload file accordingly.
+
+        Convenience method when, during development, parameter names or values are refactored but the developer
+        does not wishs to regenerate all her persistable payloads.
+
+        Parameters
+        ----------
+        new_payload_name    : str
+            New payload_name to pin to the Persistable object
+        delete_old          : bool
+            Use False to keep old parameterized payload file (sometimes useful for backwards compatibility).
+            Use True to remove the old parameterized payload file (garbage collecting and storage friendly default).
+
+        Returns
+        -------
+
+        """
+        # Rename payload file:
+        self.persistload.rename(
+            self.payload_name, new_payload_name, self.fn_params, self.fn_params, delete_old=delete_old
+        )
+
+        # Update params:
+        self.payload_name = new_payload_name
+
     def load_generate(self, **untracked_payload_params):
         """
         Like load() but executes the generate() method if load() fails due to a FileNotFoundError.
@@ -249,6 +310,12 @@ class Persistable:
         if len(missing_params):
             raise ValueError(f"Some required parameters are missing: {missing_params}")
 
+    def _validate_params(self, params):
+        for key, value in params.items():
+            if "/" in str(value):
+                raise ValueError(f"Parameter {key} contained at least one '/', but this is not allowed.")
+
+
     def __getitem__(self, item):
         """
         For getting items more conveniently from the payload recdefaultdict
